Struct semilattice_database_session::Collection
source · pub struct Collection { /* private fields */ }Implementations
sourceimpl Collection
impl Collection
pub fn new(data: Data, id: NonZeroI32, name: impl Into<String>) -> Collection
pub fn id(&self) -> NonZeroI32
pub fn name(&self) -> &str
pub fn data(&self) -> &Data
Methods from Deref<Target = Data>
pub fn result_condition<'life0, 'life_self, 'async_recursion>(
&'life_self self,
condition: &'life0 Condition<'_>
) -> Pin<Box<dyn Future<Output = BTreeSet<NonZeroU32>> + 'async_recursion>>where
'life0: 'async_recursion,
'life_self: 'async_recursion,
pub fn result_condition<'life0, 'life_self, 'async_recursion>(
&'life_self self,
condition: &'life0 Condition<'_>
) -> Pin<Box<dyn Future<Output = BTreeSet<NonZeroU32>> + 'async_recursion>>where
'life0: 'async_recursion,
'life_self: 'async_recursion,
Returns search results by specifying [Condition].
pub fn result_field( &self, name: &Arc<String>, condition: &Field ) -> BTreeSet<NonZeroU32>
pub fn begin_search(&self) -> Search<'_>
pub fn begin_search(&self) -> Search<'_>
Create a new [Search] object.
pub fn search_field<'a>(
&'a self,
name: Arc<String>,
condition: &'a Field
) -> Search<'a>
pub fn search_field<'a>( &'a self, name: Arc<String>, condition: &'a Field ) -> Search<'a>
Create a [Search] object with the field search set.
pub fn search_activity<'a>(&'a self, condition: Activity) -> Search<'a>
pub fn search_activity<'a>(&'a self, condition: Activity) -> Search<'a>
Create a [Search] object with the activity search set.
pub fn search_term<'a>(&'a self, condition: Term) -> Search<'a>
pub fn search_term<'a>(&'a self, condition: Term) -> Search<'a>
Create a [Search] object with the term search set.
pub fn search_row<'a>(&'a self, condition: &'a Number) -> Search<'a>
pub fn search_row<'a>(&'a self, condition: &'a Number) -> Search<'a>
Create a [Search] object with the row search set.
pub fn search_default(&self) -> Search<'_>
pub fn search_default(&self) -> Search<'_>
Creates a [Search] object with a default search set. Searches for data whose term is greater than or equal to the current date and time and is active.
pub fn field_bytes(&self, row: NonZeroU32, name: &Arc<String>) -> &[u8] ⓘ
pub fn field_bytes(&self, row: NonZeroU32, name: &Arc<String>) -> &[u8] ⓘ
Returns the value of the field with the specified name in the specified row as a slice.
pub fn field_num(&self, row: NonZeroU32, name: &Arc<String>) -> f64
pub fn field_num(&self, row: NonZeroU32, name: &Arc<String>) -> f64
Returns the value of the field with the specified name in the specified row as a number.
pub fn fields(&self) -> &HashMap<Arc<String>, IdxBinary>
pub async fn insert(
&mut self,
activity: Activity,
term_begin: Term,
term_end: Term,
fields: HashMap<Arc<String>, Vec<u8>>
) -> NonZeroU32
pub async fn insert( &mut self, activity: Activity, term_begin: Term, term_end: Term, fields: HashMap<Arc<String>, Vec<u8>> ) -> NonZeroU32
Delete row.
pub async fn update(
&mut self,
row: NonZeroU32,
activity: Activity,
term_begin: Term,
term_end: Term,
fields: HashMap<Arc<String>, Vec<u8>>
)
pub async fn update( &mut self, row: NonZeroU32, activity: Activity, term_begin: Term, term_end: Term, fields: HashMap<Arc<String>, Vec<u8>> )
Update row.
pub async fn delete(&mut self, row: NonZeroU32)
pub async fn delete(&mut self, row: NonZeroU32)
Delete row.
pub fn sort<C>(
&self,
rows: &BTreeSet<NonZeroU32>,
orders: &[Order<C>]
) -> Vec<NonZeroU32>where
C: CustomSort,
pub fn sort<C>(
&self,
rows: &BTreeSet<NonZeroU32>,
orders: &[Order<C>]
) -> Vec<NonZeroU32>where
C: CustomSort,
Sort search results.
pub fn serial(&self, row: NonZeroU32) -> u32
pub fn serial(&self, row: NonZeroU32) -> u32
Returns a serial number.The serial number is incremented each time data is added.
pub fn uuid(&self, row: NonZeroU32) -> Option<u128>
pub fn uuid(&self, row: NonZeroU32) -> Option<u128>
Returns a UUID.UUID is a unique ID that is automatically generated when data is registered..
pub fn uuid_string(&self, row: NonZeroU32) -> Option<String>
pub fn uuid_string(&self, row: NonZeroU32) -> Option<String>
Returns the UUID as a string.
pub fn activity(&self, row: NonZeroU32) -> Option<Activity>
pub fn activity(&self, row: NonZeroU32) -> Option<Activity>
Returns the activity value. activity is used to indicate whether data is valid or invalid.
pub fn term_begin(&self, row: NonZeroU32) -> Option<u64>
pub fn term_begin(&self, row: NonZeroU32) -> Option<u64>
Returns the start date and time of the data’s validity period.
pub fn term_end(&self, row: NonZeroU32) -> Option<u64>
pub fn term_end(&self, row: NonZeroU32) -> Option<u64>
Returns the end date and time of the data’s validity period.
pub fn last_updated(&self, row: NonZeroU32) -> Option<u64>
pub fn last_updated(&self, row: NonZeroU32) -> Option<u64>
Returns the date and time when the data was last updated.
pub fn all(&self) -> BTreeSet<NonZeroU32>
pub fn all(&self) -> BTreeSet<NonZeroU32>
Returns all rows.